@@ -6,6 +6,7 @@ from ouimeaux.config import get_cache, WemoConfiguration
 from ouimeaux.motion import Motion
 from ouimeaux.subscribe import SubscriptionRegistry
 from ouimeaux.switch import Switch
+from ouimeaux.insight import Insight
 from ouimeaux.upnp import UPnP
 
 
@@ -75,13 +76,16 @@ class Environment(object):
             self.registry.server.set_spawn(2)
             self.registry.server.start()
 
-    def wait(self):
+    def wait(self, timeout=None):
         """
         Wait for events.
         """
         try:
-            while True:
-                gevent.sleep(1000)
+            if timeout:
+                gevent.sleep(timeout)
+            else:
+                while True:
+                    gevent.sleep(1000)
         except (KeyboardInterrupt, SystemExit, Exception):
             pass
 
@@ -111,6 +115,8 @@ class Environment(object):
             klass = Switch
         elif usn.startswith('uuid:Lightswitch'):
             klass = Switch
+        elif usn.startswith('uuid:Insight'):
+            klass = Insight
         elif usn.startswith('uuid:Sensor'):
             klass = Motion
         else:
